@@ -191,8 +191,10 @@
 #define DEFAULT_REJOIN_FULL 0
 #define DEFAULT_REJOIN_INTERVAL 60
 #define DEFAULT_REJOIN_INVITEONLY 0
-#define DEFAULT_REJOIN_UNAVAILABLE 0
+#define DEFAULT_REJOIN_UNAVAILABLE 1
 #define DEFAULT_BANNER "*** "
+#define DEFAULT_URLLOG_FILE ".URLLog"
+#define DEFAULT_URLLOG_LEVEL "PUBLIC MSGS NOTICES OPNOTES ACTIONS DCC"
 
 #define DEFAULT_ALWAYS_SPLIT_BIGGEST 1
 #define DEFAULT_AUTO_UNMARK_AWAY 0
