@@ -6,7 +6,7 @@
  *
  * See the COPYRIGHT file, or do a HELP IRCII COPYRIGHT 
  *
- * @(#)$Id: irc.h,v 1.5 2001/12/08 21:25:55 toast Exp $
+ * @(#)$Id: irc.h,v 1.5.2.1 2002/03/07 19:35:15 toast Exp $
  */
 
 #ifndef __irc_h
@@ -220,16 +220,18 @@ extern	int	break_io_processing;
 extern	int	use_flow_control;
 extern	char	*joined_nick;
 extern	char	*public_nick;
+
 extern	char	empty_string[];
 
-extern	char	irc_version[];
-extern	char	internal_version[];
+extern	const	char	irc_version[];
+extern	const	char	internal_version[];
+
 extern	char	buffer[];
-extern	char	nickname[];
+extern	char	nickname[NICKNAME_LEN + 1];
 extern	char	*ircrc_file;
-extern	char	hostname[];
-extern	char	realname[];
-extern	char	username[];
+extern	char	hostname[NAME_LEN + 1];
+extern	char	realname[REALNAME_LEN + 1];
+extern	char	username[NAME_LEN + 1];
 extern	char	*send_umode;
 extern	char	*last_notify_nick;
 extern	int	away_set;
