@@ -7,7 +7,7 @@
  *
  * See the COPYRIGHT file, or do a HELP IRCII COPYRIGHT 
  *
- * @(#)$Id: ircaux.h,v 1.4 2001/12/02 18:23:00 toast Exp $
+ * @(#)$Id: ircaux.h,v 1.4.2.2 2002/03/13 21:14:11 toast Exp $
  */
 
 #ifndef _IRCAUX_H_
@@ -45,4 +45,16 @@ extern	void	strmcat();
 extern	char	*tdiff _((time_t));
 extern	char	*tdiff2 _((time_t));
 
+#ifdef NEED_STRLCPY
+extern	int	strlcpy _((char *, char *, int));
+#endif /* NEED_STRCPY */
+
+#ifdef NEED_STRLCAT
+extern	int	strlcat _((char *, char *, int));
+#endif /* NEED_STRLCAT */
+
+#ifdef NEED_STRPBRK
+extern	char	*strpbrk _((char *, char *));
+#endif /* NEED_STRPBRK */
+
 #endif /* _IRCAUX_H_ */
