@@ -7,7 +7,7 @@
  *
  * See the COPYRIGHT file, or do a HELP IRCII COPYRIGHT 
  *
- * @(#)$Id: lastlog.h,v 1.1.1.1 1999/07/16 21:21:13 toast Exp $
+ * @(#)$Id: lastlog.h,v 1.1.1.1.2.1 2002/03/11 19:24:21 toast Exp $
  */
 
 #ifndef __lastlog_h_
@@ -46,6 +46,7 @@ typedef struct	lastlog_stru
 
 extern	void	set_lastlog_level();
 extern	int	set_lastlog_msg_level();
+extern	int	get_lastlog_msg_level _((void));
 extern	void	set_lastlog_size();
 extern	void	set_notify_level();
 extern	void	lastlog();
@@ -53,7 +54,7 @@ extern	void	add_to_lastlog();
 extern	char	*bits_to_lastlog_level();
 extern	int	real_lastlog_level();
 extern	int	real_notify_level();
-extern	int	parse_lastlog_level();
+extern	int	parse_lastlog_level _((char *, char*));
 extern	int	islogged();
 
 #endif /* __lastlog_h_ */
