@@ -5,7 +5,7 @@
  *
  * copyright (c) 1993, 1994.
  *
- * @(#)$Id: stack.h,v 1.1.1.1 1999/07/16 21:21:14 toast Exp $
+ * @(#)$Id: stack.h,v 1.1.1.1.2.1 2002/03/07 22:30:58 toast Exp $
  */
 
 #ifndef __stack_h_
@@ -24,25 +24,11 @@ extern	void	stackcmd  _((char *, char *, char *));
 #define STACK_DO_ALIAS	0x0001
 #define STACK_DO_ASSIGN	0x0002
 
-typedef	struct	setstacklist
+typedef	struct	stacklist
 {
-	int	which;
-	Hook	*list;
-	struct setstacklist *next;
-}	SetStack;
-
-typedef	struct	aliasstacklist
-{
-	int	which;
-	Alias	*list;
-	struct aliasstacklist *next;
-}	AliasStack;
-
-typedef	struct	onstacklist
-{
-	int	which;
-	Hook	*list;
-	struct onstacklist *next;
-}	OnStack;
+	struct stacklist	*next;
+	int			which;
+	void			*list;
+}	Stack;
 
 #endif /* __stack_h_ */
