@@ -33,9 +33,9 @@ extern	int	setting_nolog;
 
 char	*TimeStamp();
 char	*MakeTimeStamp(long);
-void	channel_created(char *from, char **ArgList);
-void	channel_topictime(char *from, char **ArgList);
-int	Do_Not_Log(char *from);
+void	channel_created _((char *, char **));
+void	channel_topictime _((char *, char **));
+int	Do_Not_Log _((char *));
 void	nolog();
 void	set_nolog();
 void	doleave();
@@ -47,7 +47,7 @@ void	dokline();
 void	unkline();
 void	vercmd();
 void	auto_msg();
-void	remnick(char *);
+void	remnick _((char *));
 void	do_new_window();
 void	do_kill_window();
 void	do_list_windows();
@@ -70,18 +70,18 @@ void	handle_sping_nosuchserver();
 void	sping();
 void	show_banner();
 void	umode();
-void	handle_whokill(char*, char*, char*, char*);
-void	add_to_away(char*, char*);
-int	seen_away_msg(char*, char*);
-char	*function_randread(char *);
+void	handle_whokill _((char *, char *, char *, char *));
+void	add_to_away _((char *, char *));
+int	seen_away_msg _((char *, char *));
+char	*function_randread _((char *));
 void	invitecmd();
-char	*SmallTS(const time_t*);
+char	*SmallTS _((const time_t *));
 void	awaylistcmd();
-void	set_oops(char *, char *, char*);
+void	set_oops _((char *, char *, char*));
 void	oopscmd();
 void	userhost_finger();
-void	change_server_tempbans(int, int);
-void	insert_ban(char *, char *, int);
+void	change_server_tempbans _((int, int));
+void	insert_ban _((char *, char *, int));
 void	BanTimer();
 void	handle_findd();
 void	findd();
@@ -93,6 +93,9 @@ void	dovoice();
 void	dodevoice();
 void	massvoice();
 void	massdevoice();
-void	toasttest();
+void	dmsg();
+void	set_urllog_level _((char *));
+void	set_urllog_file _((char *));
+void	add_to_urllog _((char *));
 
 #endif	/* _TOAST_H_ */
