@@ -6,6 +6,26 @@
 #ifndef _VARS_H_
 #define _VARS_H_
 
+
+/* IrcVariable: structure for each variable in the variable table */
+typedef struct
+{
+	char	*name;			/* what the user types */
+	int	type;			/* variable types, see below */
+	int	integer;		/* int value of variable */
+	char	*string;		/* string value of variable */
+	void	(*func)();		/* function to do every time variable is set */
+	char	int_flags;		/* internal flags to the variable */
+	unsigned short	flags;		/* flags for this variable */
+}	IrcVariable;
+
+/* the types of IrcVariables */
+#define BOOL_TYPE_VAR 0
+#define CHAR_TYPE_VAR 1
+#define INT_TYPE_VAR 2
+#define STR_TYPE_VAR 3
+
+
 extern	int	do_boolean();
 extern	void	set_variable _((char *, char *, char *));
 extern	int	get_int_var();
@@ -16,6 +36,8 @@ extern	char	*get_string_var();
 extern	void	init_variables();
 extern	char	*var_settings[];
 extern	char	*make_string_var();
+extern	int	variable_get _((char *, IrcVariable *));
+extern	int	variable_set _((char *, IrcVariable *));
 extern	void	set_highlight_char();
 extern	int	charset_size();
 extern	void	save_variables();
@@ -188,6 +210,8 @@ enum VAR_TYPES {
 	TIMESTAMP_VAR,
 	TRANSLATION_VAR,
 	UNDERLINE_VIDEO_VAR,
+	URLLOG_FILE_VAR,
+	URLLOG_LEVEL_VAR,
 	USE_FAKE_HOST_VAR,
 	USER_INFO_VAR,
 #define	USERINFO_VAR	USER_INFO_VAR
