@@ -9,7 +9,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: alias.c,v 1.29 2001/12/09 04:29:22 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: alias.c,v 1.29.2.1 2002/03/07 22:29:51 toast Exp $";
 #endif
 
 #include "irc.h"
@@ -292,7 +292,7 @@ static BuiltInFunctions	built_in_functions[] =
 /* alias_illegals: characters that are illegal in alias names */
 	char	alias_illegals[] = " #+-*/\\()={}[]<>!@$%^~`,?;:|'\"";
 
-static	Alias	*alias_list[] =
+Alias	*alias_list[] =
 {
 	(Alias *) 0,
 	(Alias *) 0
@@ -379,7 +379,7 @@ find_alias(list, name, unlink, match)
  * insert_alias: adds the given alias to the alias list.  The alias list is
  * alphabetized by name 
  */
-static	void	
+void	
 insert_alias(list, alias)
 	Alias	**list;
 	Alias	*alias;
