@@ -4,7 +4,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: comstud.c,v 1.29 2001/12/08 05:12:07 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: comstud.c,v 1.29.2.1 2002/03/07 19:35:40 toast Exp $";
 #endif
 
 #include <stdio.h>
@@ -520,9 +520,9 @@ char *ircname;
         if (newusername)
         {
                 if (!newusername) newusername = "";
-                        strmcpy(username, newusername, NAME_LEN);
+                        strlcpy(username, newusername, sizeof(username));
                 if (ircname && *ircname)
-                        strmcpy(realname, ircname, REALNAME_LEN);
+                        strlcpy(realname, ircname, sizeof(realname));
                 do_reconnect(newnick);
         }
 }
@@ -1415,7 +1415,7 @@ char *command,
 
         if (newhname = next_arg(args, &args))
         {
-                strmcpy(MyHostName, newhname, sizeof(MyHostName));
+                strlcpy(MyHostName, newhname, sizeof(MyHostName));
                 if ((hp = gethostbyname(MyHostName)) != NULL)
                 {
                         bcopy(hp->h_addr, (char *) &MyHostAddr, sizeof(MyHostAddr));
