@@ -1,15 +1,15 @@
 /*
  * ctcp.c:handles the client-to-client protocol(ctcp). 
  *
- * Written By Michael Sandrof 
+ * Written By Timothy Jensen
  *
- * Copyright(c) 1990 
+ * Copyright (c) 1999-2001 
  *
- * See the COPYRIGHT file, or do a HELP IRCII COPYRIGHT 
+ * See the COPYRIGHT file, or do a /HELP COPYRIGHT 
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: ctcp.c,v 1.4 1999/08/19 19:01:22 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: ctcp.c,v 1.7 2001/04/01 15:58:26 toast Exp $";
 #endif
 
 #include "irc.h"
@@ -79,8 +79,10 @@ static CtcpEntry ctcp_cmd[] =
 		CTCP_VERBOSE, do_time },
 	{ "ACTION",	"contains action descriptions for atmosphere",
 		CTCP_SHUTUP, do_atmosphere },
+#ifndef DISABLE_DCC
 	{ "DCC",	"requests a direct_client_connection",
 		CTCP_SHUTUP | CTCP_NOREPLY, do_dcc },
+#endif
 	{ "UTC",	"substitutes the local timezone",
 		CTCP_SHUTUP | CTCP_NOREPLY, do_utc },
 	{ "PING", 	"returns the arguments it receives",
@@ -536,24 +538,27 @@ do_ctcp(from, to, str)
 				message_from(NULL, LOG_CTCP);
 				if (i == NUMBER_OF_CTCPS)
 				{
-					say("[%s] Unknown CTCP %s from %s to %s: %s%s", TimeStamp(),
+					/*say("[%s] Unknown CTCP %s from %s to %s: %s%s", TimeStamp(),
 						cmd, from, to, *args ? ": " :
-						empty_string, args);
+						empty_string, args);*/
+					put_it("%s", parseformat(CTCP_UNKNOWN_FMT, from, to, cmd, args));
 				}
 				else if (ctcp_flag & CTCP_VERBOSE)
 				{
 					if (my_stricmp(to,
 					    get_server_nickname(from_server)))
-						say("[%s] CTCP %s from %s to %s: %s", TimeStamp(),
-							cmd, from, to, args);
+						/*say("[%s] CTCP %s from %s to %s: %s", TimeStamp(),
+							cmd, from, to, args);*/
+						put_it("%s", parseformat(CTCP_FMT, from, to, cmd, args));
 					else
-						say("[%s] CTCP %s from %s (%s) %s%s", TimeStamp(),
+						/*say("[%s] CTCP %s from %s (%s) %s%s", TimeStamp(),
 							cmd, from,
 							FromUserHost ?
 								FromUserHost :
 								"unknown",
 							*args ? ": " :
-							empty_string, args);
+							empty_string, args);*/
+						put_it("%s", parseformat(CTCP_PRIVATE_FMT, from, to, cmd, args));
 				}
 				set_lastlog_msg_level(lastlog_level);
 			}
@@ -699,8 +704,9 @@ do_new_notice_ctcp(from, to, str, cmd)
 			}
 			lastlog_level = set_lastlog_msg_level(LOG_CTCP);
 			message_from(NULL, LOG_CTCP);
-			say("[%s] CTCP %s reply from %s: %s", TimeStamp(), cmd, from,
-				args);
+			/*say("[%s] CTCP %s reply from %s: %s", TimeStamp(), cmd, from,
+				args);*/
+			put_it("%s", parseformat(CTCP_REPLY_FMT, from, to, cmd, args));
 			set_lastlog_msg_level(lastlog_level);
 		}
 		*str = end;
