@@ -9,7 +9,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: dcc.c,v 1.4 2001/04/01 15:58:26 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: dcc.c,v 1.4.2.1 2002/03/11 20:55:31 toast Exp $";
 #endif
 
 #include "irc.h"
@@ -1079,7 +1079,7 @@ register_dcc_offer(user, type, description, address, port, size)
 	else
 	{
 		message_from(user, LOG_DCC);
-		say("Unknown DCC %s (%s) received from %s", type, description, user);
+		say("Unknown DCC %s (%s) received from %s (%s)", type, description, user, FromUserHost);
 		message_from((char *) 0, LOG_CURRENT);
 		return;
 	}
@@ -1104,7 +1104,7 @@ register_dcc_offer(user, type, description, address, port, size)
 	}
 	if (Client->flags & DCC_ACTIVE)
 	{
-		say("Received DCC %s request from %s while previous session still active", type, user);
+		say("Received DCC %s request from %s (%s) while previous session still active", type, user, FromUserHost);
 		return;
 	}
 	Client->flags |= DCC_OFFER;
@@ -1114,7 +1114,7 @@ register_dcc_offer(user, type, description, address, port, size)
 	Client->remport = TempInt;
 	if (TempInt < 1024)
 	{
-		say("DCC %s (%s) request from %s rejected", type, description, user);
+		say("DCC %s (%s) request from %s (%s) rejected", type, description, user, FromUserHost);
 		dcc_erase(Client);
 		return;
 	}
@@ -1132,13 +1132,13 @@ register_dcc_offer(user, type, description, address, port, size)
 	}
 	else if (Client->filesize)
 	{
-		say("DCC %s (%s %d) request received from %s", type, description, Client->filesize, user);
+		say("DCC %s (%s %d) request received from %s (%s)", type, description, Client->filesize, user, FromUserHost);
 		if (get_int_var(AUTO_ACCEPT_DCC_SEND_VAR))
 			dcc_auto_connect(Client);
 	}
 	else
 	{
-		say("DCC %s (%s) request received from %s", type, description, user);
+		say("DCC %s (%s) request received from %s (%s)", type, description, user, FromUserHost);
 		if (get_int_var(AUTO_ACCEPT_DCC_CHAT_VAR))
 			dcc_auto_connect(Client);
 	}
@@ -1348,7 +1348,7 @@ process_incoming_raw(Client)
 	{
 	case -1:
 #ifdef PHONE
-		say("dcc raw (%s): dgets tiomed out.  continuing...(%s)", Client->user, tmp);
+		say("dcc raw (%s): dgets timed out.  continuing...(%s)", Client->user, tmp);
 #endif
 		add_to_dcc_buffer(Client, tmp);
 		return;
@@ -1423,7 +1423,7 @@ process_incoming_talk(Client)
 	case -2: return;
 	case -1:
 #ifdef PHONE
-		say("dcc talk (%s): dgets tiomed out.  continuing...(%s)", Client->user, tmp);
+		say("dcc talk (%s): dgets timed out.  continuing...(%s)", Client->user, tmp);
 #endif
 		add_to_dcc_buffer(Client, tmp);
 		return;
