@@ -10,7 +10,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: edit.c,v 1.19 2001/12/09 04:38:13 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: edit.c,v 1.19.2.3 2002/03/11 19:24:04 toast Exp $";
 #endif
 
 #include "irc.h"
@@ -245,6 +245,7 @@ static	IrcCommand irc_command[] =
 	{ "DIGRAPH",	NULL,		digraph,		0 },
 	{ "DISCONNECT",	NULL,		disconnectcmd,		0 },
 	{ "DLINE",	"DLINE",	dokline,		0 },
+	{ "DMSG",	"PRIVMSG",	dmsg,			0 },
 	{ "ECHO",	NULL,		echo,			0 },
 	{ "ENCRYPT",	NULL,		encrypt_cmd,		0 },
 	{ "ERASE",	NULL,		clear_msgs,		0 },
@@ -370,7 +371,6 @@ static	IrcCommand irc_command[] =
 	{ "SUMMON",	"SUMMON",	send_comm,		0 },
 	{ "SWITCH",	"SWITCH",	switchcmd,		0 },
 	{ "T",		NULL,		dotopic,		0 },
-/*	{ "TEST", 	NULL,		toasttest,		0 },*/
 	{ "TIME",	"TIME",		send_comm,		0 },
 	{ "TIMER",	"TIMER",	timercmd,		0 },
 	{ "TKLINE",	"TKLINE",	dokline,		0 },
@@ -824,7 +824,7 @@ echo(command, args, subargs)
 			case 'L':
 				if (!(flag_arg = next_arg(args, &args)))
 					break;
-				if ((temp = parse_lastlog_level(flag_arg)) != 0)
+				if ((temp = parse_lastlog_level(flag_arg, "LASTLOG")) != 0)
 				{
 					lastlog_level =
 						set_lastlog_msg_level(temp);
