@@ -9,7 +9,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: format.c,v 1.14 2001/12/08 21:26:32 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: format.c,v 1.14.2.1 2002/03/07 22:29:52 toast Exp $";
 #endif
 
 #include "irc.h"
@@ -31,22 +31,6 @@ void	set_format(int, char *);
 void	set_num_format(int, char *);
 void	set_fmt(int, char *);
 
-typedef struct
-{
-	char	*name;
-	char	*fmt;
-	char	*args;
-	char	int_flags;
-} IrcFormat;
-
-typedef struct numfmt
-{
-	int	num;
-	char	*fmt;
-	char	int_flags;
-	struct numfmt *next;
-} NumFormat;
-
 #define	VIF_CHANGED	0x01
 #define	VIF_GLOBAL	0x02
 
@@ -534,3 +518,121 @@ int	FmtNum;
 	}
 	return 0;
 }
+
+int
+format_get(fmt_name, set_fmt)
+	char		*fmt_name;
+	IrcFormat	*set_fmt;
+{
+	IrcFormat	*fmt;
+	int		i = 0;
+
+	for (fmt = irc_format; fmt->name; fmt++)
+	{
+		if (!my_stricmp(fmt_name, fmt->name))
+		{
+			if (set_fmt)
+			{
+				set_fmt->name = fmt->name;
+				set_fmt->args = fmt->args;
+				malloc_strcpy(&set_fmt->fmt, fmt->fmt);
+				set_fmt->int_flags = fmt->int_flags;
+			}
+			return i;
+		}
+		i++;
+	}
+	return -1;
+}
+
+
+int
+format_set(fmt_name, set_fmt)
+	char		*fmt_name;
+	IrcFormat	*set_fmt;
+{
+	IrcFormat	*fmt;
+	int		i = 0;
+
+	for (fmt = irc_format; fmt->name; fmt++)
+	{
+		if (!my_stricmp(fmt_name, fmt->name))
+		{
+			if (set_fmt)
+			{
+				malloc_strcpy(&fmt->fmt, set_fmt->fmt);
+				fmt->int_flags = set_fmt->int_flags;
+			}
+			return i;
+		}
+		i++;
+	}
+	return -1;
+}
+
+
+int
+format_nget(fmt_num, set_fmt)
+	int		fmt_num;
+	NumFormat	*set_fmt;
+{
+	NumFormat	*fmt;
+
+	for (fmt = num_format.next; fmt; fmt = fmt->next)
+	{
+		if (fmt->num == fmt_num)
+		{
+			if (set_fmt)
+			{
+				set_fmt->num = fmt->num;
+				malloc_strcpy(&set_fmt->fmt, fmt->fmt);
+				set_fmt->int_flags = fmt->int_flags;
+			}
+			return fmt->num;
+		}
+	}
+	return -1;
+}
+
+
+int
+format_nset(fmt_num, set_fmt)
+	int		fmt_num;
+	NumFormat	*set_fmt;
+{
+	NumFormat	*fmt,
+			*last = &num_format;
+
+	for (fmt = last->next; ; fmt = fmt->next)
+	{
+		if (!fmt || (fmt->num > fmt_num))
+		{
+			if (set_fmt)
+			{
+				NumFormat	*new;
+
+				new = (NumFormat *) new_malloc(sizeof(NumFormat));
+				memset(new, 0, sizeof(NumFormat));
+				new->num = fmt_num;
+				malloc_strcpy(&new->fmt, set_fmt->fmt);
+				new->int_flags = set_fmt->int_flags;
+				new->next = last->next;
+				last->next = new;
+			}
+			return fmt_num;
+		}
+		else if (fmt->num == fmt_num)
+		{
+			if (set_fmt)
+			{
+				fmt->num = set_fmt->num;
+				malloc_strcpy(&fmt->fmt, set_fmt->fmt);
+				fmt->int_flags = set_fmt->int_flags;
+			}
+			return fmt_num;
+		}
+		last = fmt;
+	}
+	return -1;
+}
+
