@@ -9,7 +9,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: ircaux.c,v 1.8 2001/12/03 02:55:57 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: ircaux.c,v 1.8.2.2 2002/03/13 21:10:28 toast Exp $";
 #endif
 
 #include "irc.h"
@@ -1560,3 +1560,59 @@ rindex(s, c)
 }
 
 #endif /* NEED_RINDEX */
+
+#ifdef NEED_STRLCPY
+int
+strlcpy(dst, src, size)
+	char	*dst;
+	char	*src;
+	int	size;
+{
+	strncpy(dst, src, size - 1);
+	dst[size - 1] = 0;
+
+	return strlen(src);
+}
+#endif /* NEED_STRLCPY */
+
+#ifdef NEED_STRLCAT
+int
+strlcat(dst, src, size)
+	char	*dst;
+	char	*src;
+	int	size;
+{
+	int	len;
+
+	len = strlen(dst);
+	strncat(dst, src, size - len);
+	dst[size - 1] = 0;
+
+	return (len + strlen(src));
+}
+#endif /* NEED_STRLCAT */
+
+
+#ifdef NEED_STRPBRK
+char	*
+strpbrk(s, charset)
+	char	*s;
+	char	*charset;
+{
+	for (; *s; s++)
+	{
+		char	*c;
+
+		for (c = charset; *c; c++)
+		{
+			if (*s == *c)
+			{
+				return s;
+			}
+		}
+	}
+
+	return (char *) 0;
+}
+#endif /* NEED_STRPBRK */
+
