@@ -10,7 +10,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: keys.c,v 1.4 2001/12/09 05:28:30 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: keys.c,v 1.4.2.1 2002/03/08 19:32:24 toast Exp $";
 #endif
 
 #include "irc.h"
@@ -2175,3 +2175,55 @@ save_bindings(fp, do_all)
 	for (i = 0; i < charsize; i++)
 		write_binding(i, 4, fp, do_all);
 }
+
+void
+init_bindings(void)
+{
+	char	*tmp;
+	int	i;
+	int	charsize = charset_size();
+
+	for (i = 0; i < charsize; i++)
+	{
+		if (keys[i].stuff)
+		{
+			tmp = keys[i].stuff;
+			keys[i].stuff = NULL;
+
+			malloc_strcpy(&(keys[i].stuff), tmp);
+		}
+
+		if (meta1_keys[i].stuff)
+		{
+			tmp = meta1_keys[i].stuff;
+			meta1_keys[i].stuff = NULL;
+
+			malloc_strcpy(&(meta1_keys[i].stuff), tmp);
+		}
+
+		if (meta2_keys[i].stuff)
+		{
+			tmp = meta2_keys[i].stuff;
+			meta2_keys[i].stuff = NULL;
+
+			malloc_strcpy(&(meta2_keys[i].stuff), tmp);
+		}
+
+		if (meta3_keys[i].stuff)
+		{
+			tmp = meta3_keys[i].stuff;
+			meta3_keys[i].stuff = NULL;
+
+			malloc_strcpy(&(meta3_keys[i].stuff), tmp);
+		}
+
+		if (meta4_keys[i].stuff)
+		{
+			tmp = meta4_keys[i].stuff;
+			meta4_keys[i].stuff = NULL;
+
+			malloc_strcpy(&(meta4_keys[i].stuff), tmp);
+		}
+	}
+}
+
