@@ -9,7 +9,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: notice.c,v 1.8 2001/11/14 22:30:47 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: notice.c,v 1.8.2.1 2002/03/13 16:17:29 toast Exp $";
 #endif
 
 #include "irc.h"
@@ -565,7 +565,7 @@ got_initial_version(line)
 			load(empty_string, buffer, empty_string);
 		}
 		else if (get_int_var(NOVICE_VAR))
-			say("If you have not already done so, please read the new user information with /HELP NEWUSER");
+			say("If you have not already done so, please read the new user information with /HELP IRCII NEWUSER");
 	}
 	else if (server_list[from_server].away)
 		send_to_server("AWAY :%s", server_list[from_server].away);
