@@ -9,7 +9,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: server.c,v 1.12 2001/11/15 03:20:43 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: server.c,v 1.13 2002/01/08 22:04:26 toast Exp $";
 #endif
 
 #include "irc.h"
@@ -1803,7 +1803,14 @@ create_server_list()
 	for (i = 0; i < number_of_servers; i++)
 		if (server_list[i].read != -1)
 		{
-			strcat(buffer, server_list[i].itsname);
+			if (server_list[i].itsname)
+			{
+				strcat(buffer, server_list[i].itsname);
+			}
+			else if (server_list[i].name)
+			{
+				strcat(buffer, server_list[i].name);
+			}
 			strcat(buffer, " ");
 		}
 	malloc_strcpy(&value, buffer);
