@@ -12,7 +12,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: term.c,v 1.4 2001/11/13 22:11:26 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: term.c,v 1.4.2.1 2002/03/01 23:06:34 toast Exp $";
 #endif
 
 #include "irc.h"
@@ -96,6 +96,12 @@ static	char	rcsid[] = "@(#)$Id: term.c,v 1.4 2001/11/13 22:11:26 toast Exp $";
 # define USE_TERMIO
 #endif
 
+#ifdef __CYGWIN__
+# define TERMCAPSIZE	4096	/* cygwin needs a huge-ass buffer */
+#else
+# define TERMCAPSIZE	1024
+#endif
+
 /*
  * net/2 defined this as 0.5, and 4.4 as 1..
  * i hope other systems based on this don't change it (netbsd,
@@ -163,7 +169,7 @@ static	struct	termio	oldb,
 
 #ifndef STTY_ONLY
 
-static	char	termcap[1024];
+static	char	termcap[TERMCAPSIZE];
 
 /*
  * Function variables: each returns 1 if the function is not supported on the
@@ -420,7 +426,7 @@ void
 term_init()
 {
 #ifndef	STTY_ONLY
-	char	bp[1024],
+	char	bp[TERMCAPSIZE],
 		*term,
 		*ptr;
 
