@@ -3,13 +3,13 @@
  *
  * Written By Timothy Jensen
  *
- * Copyright (c) 1999-2001
+ * Copyright (c) 1999-2002
  *
  * See the COPYRIGHT file, or do a /HELP COPYRIGHT 
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: toast.c,v 1.27 2001/12/08 16:50:31 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: toast.c,v 1.29.2.6 2002/03/14 20:42:59 toast Exp $";
 #endif
 
 #include "irc.h"
@@ -17,7 +17,6 @@ static	char	rcsid[] = "@(#)$Id: toast.c,v 1.27 2001/12/08 16:50:31 toast Exp $";
 #include "vars.h"
 #include "lastlog.h"
 #include "ircaux.h"
-#include "lastlog.h"
 #include "screen.h"
 #include "window.h"
 #include "edit.h"
@@ -35,39 +34,53 @@ static	char	rcsid[] = "@(#)$Id: toast.c,v 1.27 2001/12/08 16:50:31 toast Exp $";
 #include "numbers.h"
 #include "comstud.h"
 
-char	dummy[1024];	/* Stupid temporary string */
 
-char	*auto_msg_list[AUTOMSGLISTMAX];
-int	auto_msg_list_size = 0;
-int	auto_msg_list_pos = 0;
-
-int	page_updown_key = 0;
+/******* GLOBALS *******/
 
 int	toast_action = 0;
-char	toast_arg[2048];
-int	toast_arg_int;
-int	find_cnt,find_fnd,find_type;
 
 int	in_whois = 0;
 int	bc_count;
 char	*bc_chname = 0;
 
-char	*oops_nick = (char *) 0,
-	*oops_line = (char *) 0,
-	*oops_command = (char *) 0;
+int	page_updown_key = 0;
 
 int	setting_nolog = 0;
 
+
+/******* LOCALS *******/
+
+#define DUMMY_SIZE	1024
+
+static char	dummy[DUMMY_SIZE];	/* Stupid temporary string */
+
+static char	*auto_msg_list[AUTOMSGLISTMAX];
+static int	auto_msg_list_size = 0;
+static int	auto_msg_list_pos = 0;
+
+static char	toast_arg[2048];
+static int	toast_arg_int;
+static int	find_cnt, find_fnd, find_type;
+
+static char	*oops_nick = (char *) 0,
+		*oops_line = (char *) 0,
+		*oops_command = (char *) 0;
+
 typedef struct away_struct
 {
-  char *nick;
-  char *message;
+	char *nick;
+	char *message;
 } Away;
 
-Away	last_away[10] = {{0,0},{0,0},{0,0},{0,0},{0,0},{0,0},{0,0},{0,0},{0,0},{0,0}};
+static Away	last_away[10] =
+	{{0,0},{0,0},{0,0},{0,0},{0,0},{0,0},{0,0},{0,0},{0,0},{0,0}};
 
-char *cs_channel;
-int cs_total, cs_ops, cs_here, cs_ircops, cs_hops;
+static char	*cs_channel;
+static int	cs_total, cs_ops, cs_here, cs_ircops, cs_hops;
+
+static	int	urllog_level;
+
+static	FILE	*urllog_fp = NULL;
 
 
 /*
@@ -79,22 +92,26 @@ int cs_total, cs_ops, cs_here, cs_ircops, cs_hops;
 char *
 TimeStamp(void)
 {
-  static char ts_holder[64];
-  struct tm *time_val;
-  time_t t;
-  char *ts;
+	static char	ts_holder[64];
+	struct tm	*time_val;
+	time_t		t;
+	char		*ts;
 
-  t = time(0);
-  time_val = localtime(&t);
-  ts = get_string_var(TIMESTAMP_VAR);
+	t = time(NULL);
+	time_val = localtime(&t);
+	ts = get_string_var(TIMESTAMP_VAR);
 
-  if (ts != NULL) {
-    strftime(ts_holder, 64, ts, time_val);
-    ts_holder[63] = 0;
-  } else
-    ts_holder[0] = 0;
+	if (ts != NULL)
+	{
+		strftime(ts_holder, 64, ts, time_val);
+		ts_holder[63] = 0;
+	}
+	else
+	{
+		ts_holder[0] = 0;
+	}
 
-  return (char *)&ts_holder;
+	return (char *)&ts_holder;
 }
 
 
@@ -102,20 +119,27 @@ char *
 MakeTimeStamp(thetime)
 	long	thetime;
 {
-  static char ts_holder[64];
-  struct tm *time_val;
+	static char	ts_holder[64];
+	struct tm	*time_val;
 
-  time_val = localtime((time_t *)&thetime);
+	time_val = localtime((time_t *)&thetime);
 
-  strftime(ts_holder, 64, get_string_var(TIMESTAMP_VAR), time_val);
-  ts_holder[63] = 0;
+	strftime(ts_holder, 64, get_string_var(TIMESTAMP_VAR), time_val);
+	ts_holder[63] = 0;
 
-  return (char *)&ts_holder;
+	return (char *)&ts_holder;
 }
 
 
+/* This function converts the time_t value (in string format) received
+ * from the IRC server to a human-readable date and time.
+ *
+ * Hi.  FreeBSD 5 broke this when it was named "long_to_time", which I
+ * admit was a stupid name.  Now it's a different stupid name, which
+ * hopefully FreeBSD won't break again! :-)
+ */
 char *
-long_to_time(input)
+timet_to_human(input)
         char    *input;
 {
         char    result[64];
@@ -158,7 +182,7 @@ channel_created(from, ArgList)
 	else
 	{
 		put_it("%sChannel %s created on %s", numeric_banner(), channel,
-			long_to_time(when));
+			timet_to_human(when));
 	}
 }
 
@@ -185,7 +209,7 @@ channel_topictime(from, ArgList)
 	else
 	{
         	put_it("%sTopic for %s set by %s on %s", numeric_banner(),
-			channel, nick, long_to_time(when));
+			channel, nick, timet_to_human(when));
 	}
 }
 
@@ -268,12 +292,12 @@ nolog(command, args)
 				say("Removing from NO_LOG: %s", NL_nick);
 				logremovenolog(NL_nick);
 			} else {
-				strmcat(&dummy, NLL_nick, 1024);
-				strmcat(&dummy, " ", 1024);
+				strlcat(dummy, NLL_nick, DUMMY_SIZE);
+				strlcat(dummy, " ", DUMMY_SIZE);
 			}
 		}
 		if (!flag) {
-			strmcat(&dummy, NL_nick, 1024);
+			strlcat(dummy, NL_nick, DUMMY_SIZE);
 			say("Adding to NO_LOG: %s", NL_nick);
 			logaddnolog(NL_nick);
 		}
@@ -1042,7 +1066,7 @@ show_banner(void)
 	put_it(":       \026\002                                                             \002\026");
 	put_it(":           ");
 	put_it(":           Blackened IRC version %s, an ircii-2.8.2 based client", irc_version);
-	put_it(":           Copyright (C) 2001  Timothy L. Jensen");
+	put_it(":           Copyright (C) 1999-2002  Timothy L. Jensen");
 	put_it(":             ");
 	put_it(":             Offical Website: \002http://www.blackened.com/blackened/\002");
 	put_it(":             ");
@@ -1770,25 +1794,101 @@ char *args;
 		say("No matches for massdevoice of %s on %s", spec, to);
 }
 
+
+
 void
-toasttest(command, args)
-char	*command;
-char	*args;
+dmsg(command, args, subargs)
+	char	*command,
+		*args,
+		*subargs;
 {
-	char *dump1 = NULL;
-	char *dump2 = NULL;
-	char *who, *who_uh, *server, *dead, *reason;
+	char	*tmp;
+	char	*nick;
 
-	malloc_strcpy(&dump1, "*** Notice -- Received KILL message for imanoste. From cs-pub.bu.edu Path: irc1.portal.com[156.151.6.50]!irc2.ece.uiuc.edu[128.174.64.10]!*.bu.edu[cs-pub.bu.edu]!cs-pub.bu.edu (imanoste <- irc2.ece.uiuc.edu)");
-	/*malloc_strcpy(&dump2, "*** Notice -- Received KILL message for killtest. From Toast Path: plasma.powered!toast!Toast (testing)");*/
-	malloc_strcpy(&dump2, "*** Notice -- Received KILL message for killtest. From Toast Path: lalalala!liwjer!lijs!butt.com!plasma.powered!Toast (testing)");
-
-	split_kill(dump1, &who, &who_uh, &server, &dead, &reason);
-	say("dump1 who: %s  who_uh: %s  server: %s  dead: %s  reason: %s",
-		who, who_uh, server, dead, reason);
-
-	split_kill(dump2, &who, &who_uh, &server, &dead, &reason);
-	say("dump2 who: %s  who_uh: %s  server: %s  dead: %s  reason: %s",
-		who, who_uh, server, dead, reason);
+	if ((nick = next_arg(args, &args)) != NULL)
+	{
+		tmp = new_malloc(strlen(nick) + 2);
+		if (tmp)
+		{
+			tmp[0] = '=';
+			strcpy(tmp + 1, nick);
+			send_text(tmp, args, command);
+			new_free(&tmp);
+		}
+	}
+	else
+	{
+		say("You must specify a nickname!");
+	}
 }
 
+/*
+ * set_urllog_level: called whenever a "SET URLLOG_LEVEL" is done.  It
+ * parses the settings and sets the urllog_level variable appropriately.  It
+ * also rewrites the URLLOG_LEVEL variable to make it look nice 
+ */
+void
+set_urllog_level(str)
+	char	*str;
+{
+	urllog_level = parse_lastlog_level(str, "URLLOG");
+	set_string_var(URLLOG_LEVEL_VAR, bits_to_lastlog_level(urllog_level));
+}
+
+/*
+ * set_urllog_file: called whenever a "SET URLLOG_FILE" is done.
+ */
+void
+set_urllog_file(str)
+	char	*str;
+{
+	if (urllog_fp)
+	{
+		fclose(urllog_fp);
+		urllog_fp = NULL;
+	}
+}
+
+void
+add_to_urllog(str)
+	char	*str;
+{
+	time_t	t = time(NULL);
+
+	if (get_lastlog_msg_level() & urllog_level)
+	{
+		char	*copy = NULL;
+		char	*http;
+
+		malloc_strcpy(&copy, str);
+
+		if (NULL != (http = my_strstr(copy, "http://")))
+		{
+			unsigned char	*end;
+
+			for (end = http; *end > 32; end++);
+			*end = 0;
+
+			if (!urllog_fp)
+			{
+				char	*filename = get_string_var(URLLOG_FILE_VAR);
+
+				if (filename && *filename)
+				{
+					filename = NULL;
+					malloc_strcpy(&filename, my_path);
+					malloc_strcat(&filename, "/");
+					malloc_strcat(&filename, get_string_var(URLLOG_FILE_VAR));
+					urllog_fp = fopen(filename, "a");
+					new_free(&filename);
+				}
+			}
+
+			if (urllog_fp)
+			{
+				fprintf(urllog_fp, "%s  <%s>\n", http, SmallTS(&t));
+				fflush(urllog_fp);
+			}
+		}
+	}
+}
