@@ -10,7 +10,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: vars.c,v 1.20 2001/11/29 22:10:19 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: vars.c,v 1.20.2.2 2002/03/11 19:24:05 toast Exp $";
 #endif
 
 #include "irc.h"
@@ -33,29 +33,13 @@ static	char	rcsid[] = "@(#)$Id: vars.c,v 1.20 2001/11/29 22:10:19 toast Exp $";
 #include "comstud.h"
 #include "toast.h"
 
-/* IrcVariable: structure for each variable in the variable table */
-typedef struct
-{
-	char	*name;			/* what the user types */
-	int	type;			/* variable types, see below */
-	int	integer;		/* int value of variable */
-	char	*string;		/* string value of variable */
-	void	(*func)();		/* function to do every time variable is set */
-	char	int_flags;		/* internal flags to the variable */
-	unsigned short	flags;		/* flags for this variable */
-}	IrcVariable;
-
+/* IrcVariable Flags */
 #define	VF_NODAEMON	0x0001
 
+/* IrcVariable Internal Flags */
 #define VIF_CHANGED	0x01
 #define VIF_GLOBAL	0x02
 
-/* the types of IrcVariables */
-#define BOOL_TYPE_VAR 0
-#define CHAR_TYPE_VAR 1
-#define INT_TYPE_VAR 2
-#define STR_TYPE_VAR 3
-
 char	*var_settings[] =
 {
 	"OFF", "ON", "TOGGLE"
@@ -234,6 +218,8 @@ static	IrcVariable irc_variable[] =
 	{ "TIMESTAMP",			STR_TYPE_VAR,	0, NULL, NULL, 0, 0 },
 	{ "TRANSLATION",		STR_TYPE_VAR,	0, NULL, set_translation, 0, 0 },
 	{ "UNDERLINE_VIDEO",		BOOL_TYPE_VAR,	DEFAULT_UNDERLINE_VIDEO, NULL, NULL, 0, 0 },
+	{ "URLLOG_FILE",		STR_TYPE_VAR,	0, NULL, set_urllog_file, 0, 0 },
+	{ "URLLOG_LEVEL",		STR_TYPE_VAR,	0, NULL, set_urllog_level, 0, 0 },
 	{ "USE_FAKE_HOST",		BOOL_TYPE_VAR,	0, NULL, NULL, 0, 0 },
 	{ "USER_INFORMATION", 		STR_TYPE_VAR,	0, NULL, NULL, 0, 0 },
 	{ "USER_WALLOPS",		BOOL_TYPE_VAR,	DEFAULT_USER_WALLOPS, NULL, NULL, 0, 0 },
@@ -321,6 +307,9 @@ init_variables()
 	set_string_var(OPS_METHOD_VAR, DEFAULT_OPS_METHOD);
 	set_ops_method_var(irc_variable[OPS_METHOD_VAR].string);
 	set_string_var(BANNER_VAR, DEFAULT_BANNER);
+	set_string_var(URLLOG_FILE_VAR, DEFAULT_URLLOG_FILE);
+	set_string_var(URLLOG_LEVEL_VAR, DEFAULT_URLLOG_LEVEL);
+	set_urllog_level(irc_variable[URLLOG_LEVEL_VAR].string);
 }
 
 /*
@@ -709,6 +698,70 @@ save_variables(fp, do_all)
 	}
 }
 
+
+int
+variable_get(var_name, set_var)
+	char		*var_name;
+	IrcVariable	*set_var;
+{
+	IrcVariable	*var;
+	int		i = 0;
+
+	for (var = irc_variable; var->name; var++)
+	{
+		if (!my_stricmp(var_name, var->name))
+		{
+			if (set_var)
+			{
+				set_var->name = var->name;
+				set_var->type = var->type;
+				set_var->integer = var->integer;
+				malloc_strcpy(&set_var->string, var->string);
+				set_var->func = var->func;
+				set_var->int_flags = var->int_flags;
+				set_var->flags = var->flags;
+			}
+			return i;
+		}
+		i++;
+	}
+	return -1;
+}
+
+
+int
+variable_set(var_name, set_var)
+	char		*var_name;
+	IrcVariable	*set_var;
+{
+	IrcVariable	*var;
+	int		i = 0;
+
+	for (var = irc_variable; var->name; var++)
+	{
+		if (!my_stricmp(var_name, var->name))
+		{
+			if (set_var)
+			{
+				var->type = set_var->type;
+				var->integer = set_var->integer;
+				malloc_strcpy(&var->string, set_var->string);
+				var->func = set_var->func;
+				if (var->func)
+				{
+					var->func();
+				}
+				var->int_flags = set_var->int_flags;
+				var->flags = set_var->flags;
+			}
+			return i;
+		}
+		i++;
+	}
+	return -1;
+}
+
+
 char	*
 make_string_var(var_name)
 	char	*var_name;
