@@ -11,7 +11,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: whois.c,v 1.12 2001/12/15 02:01:06 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: whois.c,v 1.12.2.1 2002/03/11 19:24:05 toast Exp $";
 #endif
 
 #undef MONITOR_Q /* this one is for monitoring of the 'whois queue' (debug) */
@@ -65,7 +65,7 @@ void
 set_beep_on_msg(str)
 	char	*str;
 {
-	beep_on_level = parse_lastlog_level(str);
+	beep_on_level = parse_lastlog_level(str, "BEEP");
 	set_string_var(BEEP_ON_MSG_VAR, bits_to_lastlog_level(beep_on_level));
 }
 
