@@ -10,7 +10,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: window.c,v 1.3 2001/11/29 22:26:49 toast Exp $";
+static	char	rcsid[] = "@(#)$Id: window.c,v 1.3.2.1 2002/03/11 19:24:05 toast Exp $";
 #endif
 
 #include "irc.h"
@@ -2262,7 +2262,7 @@ window(command, args, subargs)
 		{
 			if ((arg = next_arg(args, &args)) != NULL)
 			{
-				window->lastlog_level =parse_lastlog_level(arg);
+				window->lastlog_level = parse_lastlog_level(arg, "LASTLOG");
 				say("Lastlog level is %s",
 				  bits_to_lastlog_level(window->lastlog_level));
 			}
@@ -2273,7 +2273,7 @@ window(command, args, subargs)
 		{
 			if ((arg = next_arg(args, &args)) != NULL)
 			{
-				window->window_level = parse_lastlog_level(arg);
+				window->window_level = parse_lastlog_level(arg, "WINDOW");
 				say("Window level is %s",
 				   bits_to_lastlog_level(window->window_level));
 				revamp_window_levels(window);
@@ -2515,7 +2515,7 @@ window(command, args, subargs)
 		{
 			if ((arg = next_arg(args, &args)) != NULL)
 			{
-				window->notify_level = parse_lastlog_level(arg);
+				window->notify_level = parse_lastlog_level(arg, "NOTIFY");
 				say("Window notify level is %s",
 				   bits_to_lastlog_level(window->notify_level));
 			}
